@@ -36,8 +36,7 @@ def new_course_view(request,course_title):
     try:
         repo = Repo.objects.filter(user=request.user).get(course=course_title)
     except ObjectDoesNotExist as e:
-        if not request.user.is_superuser:
-            return render(request,'xchk_core/repo_does_not_exist.html',{'course_title': course_title})
+        pass
     # from dependent to dependencies
     course = courses.courses()[course_title]
     # from dependency to dependents
@@ -49,7 +48,11 @@ def new_course_view(request,course_title):
     if repo:
         data['repo_id'] = repo.id
         data['clone_command'] = f'git clone {repo.url}'
-    return render(request,'xchk_core/course_overview.html',data)
+    return render(request,'xchk_core/single_course_overview.html',data)
+
+def all_courses_overview_view(request):
+    courses = courses.courses()
+    return render(request,'xchk_core/all_courses_overview.html',courses)
 
 def course_map_view(request,course_title):
     structure = courses.courses()[course_title].structure
